from tkinter import *
from tkinter import ttk 
from tkinter import messagebox

def QError(name, text):
	# Error window
	messagebox.showerror(name, text)

def QWarning(name, text):
	# Warning window
	messagebox.showwarning(name, text)

def Info(name, text):
	# Information window
	messagebox.showinfo(name, text)

print('PyQwidgets Version 0.1.6\n')


import setuptools
with open(r'C:\Users\zadvo\Desktop\README.md', 'r', encoding='utf-8') as fh:
	long_description = fh.read()

setuptools.setup(
	name='PyQwidgets',
	version='0.1.6',
	author='Georg8528',
	author_email='zadvornow2908@gmail.com',
	description='This mini-framework will help you create a widget!',
	long_description=long_description,
	long_description_content_type='text/markdown',
	packages=['PyQwidgets'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)